summaryrefslogtreecommitdiff
path: root/src/mongo/db/change_stream_change_collection_manager.h
diff options
context:
space:
mode:
authorauto-revert-processor <dev-prod-dag@mongodb.com>2022-05-28 10:44:15 +0000
committerEvergreen Agent <no-reply@evergreen.mongodb.com>2022-05-28 11:11:32 +0000
commitb154f8ea0332b8829f2c7f46a8ea84c2b86f3a45 (patch)
treec0fc89a75b5c27a82d3122f0c0caacdb65c8d96c /src/mongo/db/change_stream_change_collection_manager.h
parentc9e3facf5dd94fd39066f54d44ee846f750c988b (diff)
downloadmongo-b154f8ea0332b8829f2c7f46a8ea84c2b86f3a45.tar.gz
Revert "SERVER-66123 Introduce logic to write to the change collection in the primary."
This reverts commit 1a5a5419426d512a8648914206776025beb496c4.
Diffstat (limited to 'src/mongo/db/change_stream_change_collection_manager.h')
-rw-r--r--src/mongo/db/change_stream_change_collection_manager.h17
1 files changed, 6 insertions, 11 deletions
diff --git a/src/mongo/db/change_stream_change_collection_manager.h b/src/mongo/db/change_stream_change_collection_manager.h
index 6b7de7da109..b4ad0e25c50 100644
--- a/src/mongo/db/change_stream_change_collection_manager.h
+++ b/src/mongo/db/change_stream_change_collection_manager.h
@@ -75,21 +75,16 @@ public:
Status dropChangeCollection(OperationContext* opCtx, boost::optional<TenantId> tenantId);
/**
* Inserts documents to change collections. The parameter 'oplogRecords'
* is a vector of oplog records and the parameter 'oplogTimestamps' is a vector for respective
* timestamp for each oplog record.
*
- * The method fetches the tenant-id from the oplog entry, performs necessary modification to the
- * document and then write to the tenant's change collection at the specified oplog timestamp.
- *
- * Failure in insertion to any change collection will result in a fatal exception and will bring
- * down the node.
- *
* TODO: SERVER-65950 make tenantId field mandatory.
*/
- void insertDocumentsToChangeCollection(OperationContext* opCtx,
- const std::vector<Record>& oplogRecords,
- const std::vector<Timestamp>& oplogTimestamps);
+ Status insertDocumentsToChangeCollection(OperationContext* opCtx,
+ boost::optional<TenantId> tenantId,
+ std::vector<Record>* records,
+ const std::vector<Timestamp>& timestamps);
};
} // namespace mongo
@@ -75,21 +75,16 @@ public:
Status dropChangeCollection(OperationContext* opCtx, boost::optional<TenantId> tenantId);
/**
- * Inserts documents to change collections. The parameter 'oplogRecords'
- * is a vector of oplog records and the parameter 'oplogTimestamps' is a vector for respective
+ * Inserts documents to the change collection for the specified tenant. The parameter 'records'
+ * is a vector of oplog records and the parameter 'timestamps' is a vector for respective
* timestamp for each oplog record.
*